import { Component, render, h } from 'preact';
import NoticeBarContainer from './components/NoticeBar/index';
import GlobalStyled from './GlobalStyled';
import styled, { ThemeProvider } from 'styled-components';
import getTheme from './styles/theme';
import ModalContainer from './components/Modal';
import GaTracker from './utils/context/gaTracker';
import CookiesConfig from './utils/context/config';
import OverlayState from './components/OverlayContext';
import OverlayContainer from './components/Overlay';
import ToggleButtonContainer from './components/ToggleButton';
import { LanguageState, contextLanguageFucntion } from './locales';
import { checkGoogleAnalytic, getCookies } from './service/cookie';

const Wrapper = styled.div``;

export class App extends Component {
  state = {
    isApplied: false
  };
  constructor() {
    super();
    this.state = {
      colorPrimary: '',
      colorSecondary: '',
      colorHover: '',
      colorIcon: ''
    };
  }

  componentDidMount() {
    checkGoogleAnalytic(this.props.config);
    this.setState({
      isApplied: !!getCookies()
    });
  }

  render() {
    const ga = this.props.ga || window.ga;
    const hideAfterApply = this.props.hideAfterApply;

    return (
      <ThemeProvider
        theme={() =>
          getTheme(
            {
              colorPrimary:
                this.state.colorPrimary || this.props.colorList.colorPrimary,
              colorSecondary:
                this.state.colorSecondary ||
                this.props.colorList.colorSecondary,
              hoverColor:
                this.state.colorHover || this.props.colorList.hoverColor,
              iconColor: this.state.colorIcon || this.props.colorList.iconColor
            },
            this.props.fontFamily
          )
        }
      >
        <Wrapper>
          <LanguageState locale={this.props.locale}>
            <CookiesConfig config={this.props.config}>
              <GaTracker ga={ga}>
                <OverlayState>
                  <GlobalStyled />
                  {hideAfterApply && this.state.isApplied ? null : (
                    <ToggleButtonContainer
                      placement={this.props.config.placement}
                    />
                  )}
                  <NoticeBarContainer
                    policyLink={this.props.policy}
                    showSetting={this.props.showSetting}
                    showPolicyLink={this.props.showPolicyLink}
                    onApply={() => {
                      this.setState({
                        isApplied: true
                      });
                    }}
                  />
                  <ModalContainer
                    onSave={() => {
                      this.setState({
                        isApplied: true
                      });
                    }}
                  />
                  <OverlayContainer />
                </OverlayState>
              </GaTracker>
            </CookiesConfig>
          </LanguageState>
        </Wrapper>
      </ThemeProvider>
    );
  }
}

const renderWeb = ({
  locale,
  performance,
  googleAnalytic,
  marketing,
  ga,
  colorPrimary,
  colorSecondary,
  iconColor,
  hoverColor,
  policy,
  fontFamily,
  essential,
  fbq,
  fbPixel,
  showPolicyLink = true,
  showSetting = true,
  settingOptions = ['essential', 'performance', 'analytic', 'marketing'],
  placement = 'left',
  hideAfterApply
}) => {
  const element = document.createElement('div');
  element.id = 'cookie-handler-gdpr';
  element.className = 'cookie-handler-gdpr';
  render(
    <App
      ref={component => {
        window.component = component;
      }}
      locale={locale}
      ga={ga}
      config={{
        essential,
        performance,
        googleAnalytic,
        marketing,
        fbq,
        fbPixel,
        settingOptions,
        placement
      }}
      colorList={{ colorPrimary, colorSecondary, hoverColor, iconColor }}
      policy={policy}
      showPolicyLink={showPolicyLink}
      showSetting={showSetting}
      fontFamily={fontFamily}
      hideAfterApply={hideAfterApply}
    />,
    element
  );
  document.body.appendChild(element);

  return { setLanguage };
};

const setLanguage = locale => {
  const languageContext = contextLanguageFucntion();
  languageContext().getLanguageData(locale);
};

export default renderWeb;
