const HtmlWebPackPlugin = require("html-webpack-plugin");
const { CleanWebpackPlugin } = require("clean-webpack-plugin");
const path = require("path");

module.exports = {
  mode: "development",
  entry: [
    path.resolve("./src/index.js"),
    path.resolve("./src/exposeGlobal.js")
  ],
  devtool: "inline-source-map",
  devServer: {
    contentBase: path.resolve("./public")
  },
  module: {
    rules: [
      {
        test: /\.jsx?$/,
        exclude: path.resolve(__dirname, "src"),
        enforce: "pre",
        use: "source-map-loader"
      },
      {
        test: /\.(js)$/,
        include: path.resolve(__dirname, "src"),
        use: [
          {
            loader: "babel-loader"
          },
          {
            loader: "eslint-loader"
          }
        ]
      },
      {
        test: /\.(svg)$/i,
        use: [
          {
            loader: "url-loader",
            options: {
              limit: 8192
            }
          }
        ]
      }
    ]
  },
  resolve: {
    alias: {
      react: "preact/compat",
      "react-dom": "preact/compat"
    }
  },
  plugins: [
    new HtmlWebPackPlugin({
      inject: true,
      template: path.resolve("./public/index.html")
    }),
    new CleanWebpackPlugin()
  ]
};
